@@ -7,4 +7,4 @@ from .selectped import selectPed
 from .plot import cluster, heat,gragh, pca
 from .coef import coefKinship,coefInbreeding
 from .inter_matrix import makeG_inter
-from .mmatrix import makeM
\ No newline at end of file
+from .mmatrix import makeM, makeT
\ No newline at end of file
