@@ -1,4 +1,3 @@
-##显性效应怎么标准化？
 
 import numpy as np
 #import math
@@ -70,8 +69,8 @@ def one_matrix(geno,start,end,step):
     zz11 = np.zeros((geno.shape[0],geno.shape[0]))
     for i in range(start,end,step):
         zz00 = geno[:,:-i] * geno[:,i:]
-        zz11 += (zz00.dot(zz00.T)).astype(np.float64)   ##转置相乘float32就够，但是下一步加在一起，可能几十万或者几百万会影响精度
-
+        zz11 += (zz00.dot(zz00.T)).astype(np.float64)   
+        print(i)
     return zz11
 
 @nb.njit(parallel=True)
@@ -79,8 +78,8 @@ def ad_matrix(geno,Z,start,end,step):
     zz11 = np.zeros((geno.shape[0],geno.shape[0]))
     for i in range(start,end,step):
         zz00 = Z[:,:-i] * geno[:,i:]
-        zz11 += (zz00.dot(zz00.T)).astype(np.float64)   ##转置相乘float32就够，但是下一步加在一起，可能几十万或者几百万会影响精度
-
+        zz11 += (zz00.dot(zz00.T)).astype(np.float64)  
+        print(i)
     return zz11
     
 @nb.njit(parallel=True)
@@ -89,23 +88,23 @@ def da_matrix(geno,Z,start,end,step):
     zz11 = np.zeros((geno.shape[0],geno.shape[0]))
     for i in range(start,end,step):
         zz00 =geno[:,:-i] * Z[:,i:]
-        zz11 += (zz00.dot(zz00.T)).astype(np.float64)   ##转置相乘float32就够，但是下一步加在一起，可能几十万或者几百万会影响精度
-
+        zz11 += (zz00.dot(zz00.T)).astype(np.float64)  
+        print(i)
     return zz11
 
 def makematrix(geno,start,end,method,step):
     if method == 'dd':
-        geno[geno==2] = 0  ### W矩阵
+        geno[geno==2] = 0  ### W matrix
         zz11 = one_matrix(geno,start,end,step)
     if method =='aa':
         zz11 = one_matrix(geno,start,end,step)
     if method =='ad':
-        Z = geno  ###Z矩阵
-        geno[geno==2] = 0  ### W矩阵
+        Z = geno  ###Z matrix
+        geno[geno==2] = 0 
         zz11 = ad_matrix(geno,Z,start,end,step)
     if method =='da':
-        Z = geno  ###Z矩阵
-        geno[geno==2] = 0  ### W矩阵
+        Z = geno 
+        geno[geno==2] = 0  
         zz11 = da_matrix(geno,Z,start,end,step)
     return zz11
 
@@ -122,7 +121,7 @@ def makeG_inter(geno,method,multi=1):
     if method not in method_list:
         print("ERROR: Parameter method should be in %s" %method_list)
         return
-    ###输入的geno,行是个体，列是snp，编码为012
+
     if not isinstance(geno, np.ndarray):
         print("ERROR: geno data should be numpy ndarray type")
         return
